@@ -2,8 +2,8 @@ import pdb
 import requests
 
 from stoobly_agent.lib.api.projects_resource import ProjectsResource
-from stoobly_agent.lib.api.interfaces import ProjectCreateParams
-from stoobly_agent.lib.api.keys import OrganizationKey
+from stoobly_agent.lib.api.interfaces import ProjectCreateParams, ProjectShowResponse, ProjectsIndexQueryParams, ProjectsIndexResponse
+from stoobly_agent.lib.api.keys import OrganizationKey, ProjectKey
 from stoobly_agent.app.settings import Settings
 
 class ProjectFacade():
@@ -12,7 +12,7 @@ class ProjectFacade():
     self.__settings = __settings
     self.__api = ProjectsResource(self.__settings.remote.api_url, self.__settings.remote.api_key)
 
-  def create(self, **kwargs: ProjectCreateParams):
+  def create(self, **kwargs: ProjectCreateParams) -> ProjectShowResponse:
     organization_key: str = OrganizationKey(kwargs.get('organization_key')) 
 
     res: requests.Response =  self.__api.create(
@@ -26,11 +26,18 @@ class ProjectFacade():
 
     return res.json()
 
-  def index(self, **kwargs):
+  def show(self, project_key: str) -> ProjectShowResponse:
+    key = ProjectKey(project_key)
+    res = self.__api.show(key.id)
+    return res.json()
+
+  def index(self, kwargs) -> ProjectsIndexResponse:
     organization_key: str = OrganizationKey(kwargs.get('organization_key')) 
 
     del kwargs['organization_key']
 
     res = self.__api.index(**{ 'organization_id': organization_key.id,  **kwargs })
 
-    return res.json()
\ No newline at end of file
+    return res.json()
+
+  
\ No newline at end of file
