@@ -7,4 +7,4 @@ from .request_show_response import QueryParam, RequestShowResponse
 from .requests_index_query_params import RequestsIndexQueryParams
 from .requests_index_response import RequestsIndexResponse
 from .response_show_response import ResponseShowResponse
-from .scenarios_index_response import ScenariosIndexResponse
\ No newline at end of file
+from .scenarios import ScenarioShowResponse, ScenariosIndexResponse
\ No newline at end of file
